@@ -21,6 +21,7 @@ val load : unit -> unit
 val save : unit -> unit
 val save_sources : unit -> unit
 val backup_options : unit -> unit
+val allow_saving_ini_files : bool ref
   
 val done_files :  CommonTypes.file list Options.option_record
 val files :  CommonTypes.file list Options.option_record
@@ -33,16 +34,17 @@ val customized_queries : unit ->
   (string * CommonTypes.query_entry) list 
 val special_queries : (string * string) list Options.option_record
   
-val sharing_strategies : string -> CommonTypes.sharing_strategy
+val sharing_strategies : (string * CommonTypes.sharing_strategy) list Options.option_record
+val sharing_strategy : string -> CommonTypes.sharing_strategy
 
 val shared_directories : 
   CommonTypes.shared_directory list Options.option_record
   
-val incoming_files : unit -> CommonTypes.shared_directory
-val incoming_directories : unit -> CommonTypes.shared_directory
-val search_incoming_files : unit -> CommonTypes.shared_directory
-val search_incoming_directories : unit -> CommonTypes.shared_directory
-  
+val incoming_dir : bool -> ?user:CommonTypes.userdb -> ?needed_space:int64 -> ?network:string -> unit -> CommonTypes.shared_directory
+val search_incoming_files : unit -> CommonTypes.shared_directory list
+val search_incoming_directories : unit -> CommonTypes.shared_directory list
+val shared_directories_including_user_commit : unit -> CommonTypes.shared_directory list
+
 val sharing_only_directory : CommonTypes.sharing_strategy
 
 val swarmers_section : Options.options_section
