@@ -323,7 +323,7 @@ let file_best_name (file : file) =
   let file = as_file_impl file in
   file.impl_file_best_name
   
-let set_file_best_name file name fs namemax =
+let set_file_best_name file name ?(fs=`Unknown) namemax =
   let file = as_file_impl file in
   let old_name = file.impl_file_best_name in
   let real_name = Filename2.filesystem_compliant name fs namemax in
@@ -1265,13 +1265,13 @@ let impl_file_info impl =
     T.file_release = impl.impl_file_release;
   }
 
-let lprintf_file_nl file fmt =
-  lprintf_nl2 ("[" ^ (file_network file).network_shortname ^
+let lprintf_file_nl ?exn file fmt =
+  lprintf_nl2 ?exn ("[" ^ (file_network file).network_shortname ^
 	       "] [file_num " ^ (string_of_int (file_num file)) ^ "]" ^
 	       "[temp " ^ (file_disk_name file) ^ "]") fmt
 
 let concat_file dir filename =
-  let fs = Unix32.filesystem dir in
+  let fs = Unix32.filesystem_type dir in
   let namemax =
     match Unix32.fnamelen dir with
     | None -> 0
