@@ -87,6 +87,7 @@ let country_stats = define_option country_stats_section ["country_stats"]
   "Country-based traffic statistics" (list_option CountryStatsOption.t) []
 
 let country_stats_find cc =
+  let cc = Geoip.country_code_array.(cc) in
   try
     List.find (fun c -> c.country_code = cc) !!country_stats
   with Not_found ->
@@ -104,38 +105,35 @@ let country_stats_find cc =
     country_stats =:= cs :: !!country_stats;
     cs
 
-let country_upload ip v =
-  try
-    let cc,_ = Geoip.get_country ip in
+let country_upload cc v =
+  match cc with | None -> ()
+  | Some cc ->
     let c = country_stats_find cc in
     c.country_session_upload <- c.country_session_upload ++ v;
     c.country_total_upload <- c.country_total_upload ++ v
-  with _ -> ()
 
-let country_download ip v =
-  try
-    let cc,_ = Geoip.get_country ip in
+let country_download cc v =
+  match cc with | None -> ()
+  | Some cc ->
     let c = country_stats_find cc in
     c.country_session_download <- c.country_session_download ++ v;
     c.country_total_download <- c.country_total_download ++ v
-  with _ -> ()
 
-let country_seen ip =
-  try
-    let cc,_ = Geoip.get_country ip in
+let country_seen cc =
+  match cc with | None -> ()
+  | Some cc ->
     let c = country_stats_find cc in
     c.country_session_seen <- c.country_session_seen ++ 1L;
     c.country_total_seen <- c.country_total_seen ++ 1L
-  with _ -> ()
 
-let global_count_upload n ip v =
+let global_count_upload n cc v =
   upload_counter := !upload_counter ++ v;
-  country_upload ip v;
+  country_upload cc v;
   network_must_update n
 
-let global_count_download n ip v =
+let global_count_download n cc v =
   download_counter := !download_counter ++ v;
-  country_download ip v;
+  country_download cc v;
   network_must_update n
 
 let find_int_of_brand brand brand_list =
@@ -320,27 +318,27 @@ let print_stats_ascii buf arr l tl uptime =
 
 
 let stats_html_header buf =
-  html_mods_table_header buf "csTable" "cs" [
-   ( "0", "srh", "Client brand", "Brand" );
-   ( "0", "srh", "Separator", ":" );
-   ( "1", "srh ar", "Successful connections", "Seen" );
-   ( "1", "srh", "Successful connections percent", "%" );
-   ( "0", "srh", "Separator", "|" );
-   ( "1", "srh ar", "File requests received", "Reqs" );
-   ( "1", "srh", "File requests received percent", "%" );
-   ( "0", "srh", "Separator", "|" );
-   ( "1", "srh ar", "Total bans", "B" );
-   ( "1", "srh", "Total bans percent", "%" );
-   ( "0", "srh", "Separator", "|" ); 
-   ( "1", "srh ar", "Total uploads", "UL" );
-   ( "1", "srh", "Total uploads percent", "%" );
-   ( "1", "srh ar", "Total uploads average KB/s", "KB/s" );
-   ( "0", "srh", "Separator", "|" );
-   ( "1", "srh ar", "Total downloads", "DL" );
-   ( "1", "srh", "Total downloads percent", "%" );
-   ( "1", "srh ar", "Total downloads average KB/s", "KB/s" );
-   ( "0", "srh", "Separator", "|" );
-   ( "1", "srh", "Total uploads:downloads ratio", "U:DL" );
+  html_mods_table_header buf ~total:"1" "csTable" "cs" [
+   ( Str, "srh", "Client brand", "Brand" );
+   ( Str, "srh", "Separator", ":" );
+   ( Num, "srh ar", "Successful connections", "Seen" );
+   ( Num, "srh", "Successful connections percent", "%" );
+   ( Str, "srh", "Separator", "|" );
+   ( Num, "srh ar", "File requests received", "Reqs" );
+   ( Num, "srh", "File requests received percent", "%" );
+   ( Str, "srh", "Separator", "|" );
+   ( Num, "srh ar", "Total bans", "B" );
+   ( Num, "srh", "Total bans percent", "%" );
+   ( Str, "srh", "Separator", "|" ); 
+   ( Num, "srh ar", "Total uploads", "UL" );
+   ( Num, "srh", "Total uploads percent", "%" );
+   ( Num, "srh ar", "Total uploads average KB/s", "KB/s" );
+   ( Str, "srh", "Separator", "|" );
+   ( Num, "srh ar", "Total downloads", "DL" );
+   ( Num, "srh", "Total downloads percent", "%" );
+   ( Num, "srh ar", "Total downloads average KB/s", "KB/s" );
+   ( Str, "srh", "Separator", "|" );
+   ( Num, "srh", "Total uploads:downloads ratio", "U:DL" );
   ]
 
 let stats_list l arr = 
@@ -463,5 +461,5 @@ let _ =
   Heap.add_memstat "CommonStats" (fun level buf ->
     Printf.bprintf buf "  countries: %d%s\n"
       (List.length !!country_stats)
-      (if not !Geoip.active then " - Geoip not active" else "");
+      (if not (Geoip.active ()) then " - Geoip not active" else "");
    )
