@@ -22,10 +22,6 @@ val eval : bool ref -> string -> CommonTypes.ui_conn -> unit
 
   
 val telnet_handler : TcpServerSocket.t -> TcpServerSocket.event -> unit
-val chat_handler : TcpServerSocket.t -> TcpServerSocket.event -> unit
 val create_http_handler : unit -> unit
 
 val check_calendar : unit -> unit
-
-(* should not be here ... *)
-val text_of_html : string -> string
