@@ -533,9 +533,9 @@ let gui_reader (gui: gui_record) t _ =
     
     | GuiProtocol version ->
         let version = min GuiProto.best_gui_version version in
-        gui.gui_proto_to_gui_version <- Array.create 
+        gui.gui_proto_to_gui_version <- Array.make 
           (to_gui_last_opcode + 1) version;
-        gui.gui_proto_from_gui_version <- Array.create 
+        gui.gui_proto_from_gui_version <- Array.make 
           (from_gui_last_opcode + 1) version;
         if not !verbose_no_login then lprintf_nl "GUI protocol %d" version    
     
@@ -831,7 +831,7 @@ let gui_reader (gui: gui_record) t _ =
           
           | P.SaveFile (num, name) ->
               let file = file_find num in
-              set_file_best_name file name "" 0;
+              set_file_best_name file name 0;
               (match file_state file with
                   FileDownloaded ->
                     file_save_as file name;
@@ -888,7 +888,7 @@ let gui_reader (gui: gui_record) t _ =
           
           | P.RenameFile (num, new_name) ->
               let file = file_find num in
-              set_file_best_name file new_name "" 0;
+              set_file_best_name file new_name 0;
               addevent gui.gui_events.gui_files num true
           
           | P.ConnectFriend num 
@@ -1159,8 +1159,8 @@ let new_gui gui_send gui_auth sock gui_type =
       gui_sock = sock;
       gui_search_nums = [];
       gui_events = gui_events ();
-      gui_proto_to_gui_version = Array.create (to_gui_last_opcode+1) 0;
-      gui_proto_from_gui_version = Array.create (from_gui_last_opcode+1) 0;
+      gui_proto_to_gui_version = Array.make (to_gui_last_opcode+1) 0;
+      gui_proto_from_gui_version = Array.make (from_gui_last_opcode+1) 0;
       gui_num = !gui_counter;
       gui_auth = gui_auth;
       gui_poll = false;
