@@ -42,7 +42,7 @@ open GuiProto
 module M = Gui_messages
 
 
-let mldonkey_cache = Filename.concat CommonOptions.config_dir "cache" 
+let mldonkey_cache = Filename.concat CommonOptions.home_dir "cache" 
   
 let file_from_url url = 
   try
@@ -81,7 +81,7 @@ let request_and_parse parse_fun  url wtree =
         parse_fun wtree page)
     (fun pos max ->
         counter := !counter + pos;
-        lprintf "pos: %d/%d" !counter max; lprint_newline (); 
+        lprintf "pos: %d/%Ld" !counter max; lprint_newline (); 
     )
 
 
