@@ -40,20 +40,17 @@ let chmod_config () =
   let save_config =
     base_config^".old"
   in
-  begin
-    if Sys.file_exists base_config then
-      Printexc2.catch2 "Unix.chmod" Unix.chmod base_config 0o600 
-    else
-      ()
-  end;
-  begin
-    if Sys.file_exists save_config then
-      Printexc2.catch2 "Unix.chmod" Unix.chmod save_config 0o600
-    else
-      ()
-  end
-  
-let _ = 
+  let chmod file =
+    if Sys.file_exists file then
+      try
+        Unix.chmod file 0o600 
+      with
+        exn -> lprintf "Exception: chmod %s 0600 : %s\n" file (Printexc2.to_string exn)
+  in
+  chmod base_config;
+  chmod save_config
+
+let () = 
   (try Options.load O.mldonkey_gui_ini with
       Sys_error _ ->
 	(try Options.save O.mldonkey_gui_ini with _ -> ())
@@ -70,7 +67,7 @@ let _ =
   Arg.parse args (Arg.usage args)  "mlgui: the GUI to use with mldonkey"
   
 (* Check bindings *)
-let _ = 
+let () = 
   if !!O.keymap_global = [] then
     (
      let a = O.add_binding O.keymap_global in
@@ -625,6 +622,6 @@ let main () =
         never_connected := false
   )
   
-let _ = 
+let () = 
   CommonGlobals.gui_included := true;
   main ()
