@@ -1050,11 +1050,13 @@ let string_of_tag_name name =
     | Field_Completesources -> "completesources"
     | Field_Filename -> "filename"
     | Field_Size -> "size"
+    | Field_Size_Hi -> "size_hi"
     | Field_Uid -> "uid"
     | Field_Medialength -> "length"
     | Field_Mediacodec -> "codec"
     | Field_Lastseencomplete -> "lastseencompl"
     | Field_Filerating -> "rating"
+    | Field_KNOWN s -> U.simple_utf8_of s
     | Field_UNKNOWN s -> U.simple_utf8_of s
   
 let tags_to_string tags =
@@ -1276,8 +1278,8 @@ let client_to_source c =
      source_connect_time    = BasicSocket.last_time () - c.client_connect_time;
      source_last_seen       = BasicSocket.current_time ();
      source_software        = concat_strings c.client_software (concat_strings c.client_emulemod c.client_release);
-     source_downloaded      = c.client_downloaded;
-     source_uploaded        = c.client_uploaded;
+     source_downloaded      = c.client_total_downloaded;
+     source_uploaded        = c.client_total_uploaded;
      source_upload_rate     = 0.;
      source_download_rate   = 0.;
      source_upload          = c.client_upload;
