@@ -725,9 +725,6 @@ let set_default_codeset_list lang =
   enc_list := List.map (fun c -> codeset_to_string c ) (codeset_list_from_lang lang);
   enc_list := List.filter (fun enc -> enc <> charset) !enc_list;
   enc_list := if (charset <> "UTF-8") then charset::!enc_list else !enc_list;
-  List.iter (fun enc ->
-    lprintf "Use encoding %s\n" enc
-  ) !enc_list;
   nenc := List.length !enc_list
 
 let last_chance_to_encode s =
