@@ -39,6 +39,25 @@ let lprintf_nl fmt =
 
 let is_enabled = ref false
 
+let stop_dht () =
+  match !bt_dht with
+  | None -> ()
+  | Some dht ->
+    if !verbose then lprintf_nl "stopping DHT";
+    BT_DHT.stop dht;
+    bt_dht := None
+
+let start_dht () =
+  let already = match !bt_dht with Some dht -> dht.BT_DHT.M.dht_port = !!dht_port | None -> false in
+  if not already && !!dht_port > 0 then
+  begin
+    stop_dht ();
+    lprintf_nl "starting DHT on port %d" !!dht_port;
+    let dht = BT_DHT.start !!dht_routing_table !!dht_port CommonGlobals.udp_write_controler in
+    BT_DHT.bootstrap dht ~routers:!!dht_bootstrap_nodes;
+    bt_dht := Some dht
+  end
+
 let disable enabler () =
   if !enabler then begin
       is_enabled := false;
@@ -51,67 +70,48 @@ let disable enabler () =
             listen_sock := None;
             TcpServerSocket.close sock Closed_by_user);
       BTTracker.stop_tracker ();
+      stop_dht ();
       if !!enable_bittorrent then enable_bittorrent =:= false
     end
 
 let enable () =
-  (* lprintf "enable\n"; *)
   if not !is_enabled then
     let enabler = ref true in
-    (* lprintf "enabling...\n"; *)
-    Unix2.safe_mkdir torrents_directory;
-    Unix2.safe_mkdir seeded_directory;
-    Unix2.safe_mkdir tracked_directory;
-    Unix2.safe_mkdir downloads_directory;
-    Unix2.safe_mkdir old_directory;
-    Unix2.safe_mkdir new_torrents_directory;
-    Unix2.can_write_to_directory torrents_directory;
-    Unix2.can_write_to_directory seeded_directory;
-    Unix2.can_write_to_directory tracked_directory;
-    Unix2.can_write_to_directory downloads_directory;
-    Unix2.can_write_to_directory old_directory;
-    Unix2.can_write_to_directory new_torrents_directory;
+    List.iter (fun dir ->
+      Unix2.safe_mkdir dir;
+      Unix2.can_write_to_directory dir;
+    )  [torrents_directory; seeded_directory;
+        tracked_directory; downloads_directory;
+        old_directory; new_torrents_directory];
     is_enabled := true;
     if !!BTTracker.tracker_port = !!client_port then
       begin
         lprint_newline();
-  lprintf_nl "BT-client_port and BT-tracker_port can not be the same.";
-  lprintf_nl "Change one of the settings and restart MLDonkey, exiting...\n";
-	Pervasives.exit 69
+        lprintf_nl "BT-client_port and BT-tracker_port can not be the same.";
+        lprintf_nl "Change one of the settings and restart MLDonkey, exiting...\n";
+        Pervasives.exit 69
       end;
     if !!BTTracker.tracker_port > 0 then (
-        try BTTracker.start_tracker ()
+        try BTTracker.start_tracker !!tracked_files_list
         with e ->
             lprintf "Exception in BTTracker.start_tracker: %s\n"
               (Printexc2.to_string e));
-    add_session_timer enabler 300. (fun _ ->
-        BTInteractive.share_files ();
+    start_dht ();
+    if !!share_scan_interval <> 0 then
+    add_session_timer enabler (float_of_int (!!share_scan_interval * 60))
+      (fun _ -> BTInteractive.share_files ();
     );
     if !!import_new_torrents_interval <> 0. then
     add_session_timer enabler !!import_new_torrents_interval (fun _ ->
         BTInteractive.scan_new_torrents_directory ();
     );
+    add_session_timer enabler 60. (fun _ -> BTInteractive.announce_shared_files (); );
+    add_timer 5. (fun _ -> BTInteractive.scan_new_torrents_directory ());
     add_timer 10. BTInteractive.share_files;
     add_session_timer enabler 600. BTInteractive.retry_all_ft;
     network.op_network_disable <- disable enabler;
 
     if not !!enable_bittorrent then enable_bittorrent =:= true;
-(*
-  List.iter (fun s ->
-      try
-        let ip = Ip.from_name s in
-        redirectors_ips := ip :: !redirectors_ips
-      with _ -> ()
-  ) !!redirectors;
-*)
-
-(*
-  Hashtbl.iter (fun _ file ->
-      if file_state file <> FileDownloaded then
-        current_files := file :: !current_files
-  ) files_by_key;
-*)
-
 
     BTClients.recover_files ();
     add_session_timer enabler 60.0 (fun timer ->
@@ -127,19 +127,25 @@ let enable () =
 
   CommonGlobals.do_at_exit ( fun _ ->
     List.iter (fun file ->
-		 BTClients.file_stop file
-	      ) !current_files;
+                 BTClients.file_stop file
+              ) !current_files;
   );
 
   BTClients.listen ();
   ()
 
 let _ =
+  CommonOptions.verbose_dht := Kademlia.verb;
   network.op_network_is_enabled <- (fun _ -> !!CommonOptions.enable_bittorrent);
   option_hook enable_bittorrent (fun _ ->
       if !CommonOptions.start_running_plugins then
       if !!enable_bittorrent then network_enable network
       else network_disable network);
+  option_hook dht_port (fun _ ->
+    if !is_enabled then
+    begin
+      if !!dht_port = 0 then stop_dht () else start_dht ()
+    end);
 (*
   network.op_network_save_simple_options <- BTComplexOptions.save_config;
   network.op_network_load_simple_options <-
