@@ -49,12 +49,11 @@ them.
 
 (*
 
-torrents/: for BitTorrent
-  downloads/: .torrent files of current downloads
-  tracked/: .torrent files of tracked downloads
-    * If the file appears in incoming/, it is automatically seeded.
-  seeded/:
-     * If the file appears in incoming/, it is automatically seeded.
+torrents/: .torrent files
+  downloads/: current downloads
+  seeded/: currently seeding
+  incoming/: monitored for new torrents to start downloading
+  old/: no content available
 
   *)
 
@@ -97,19 +96,19 @@ let ntracked_files = ref 0
 
 let tracker_port = define_option bittorrent_section ["tracker_port"]
   ~restart: true
-  "The port to bind the tracker to"
-    int_option 6881
+  "The port to bind the tracker to (0 to disable)"
+    port_option 6881
 
 let max_tracked_files = define_option bittorrent_section ["max_tracked_files"]
-  "The maximal number of tracked files (to prevend saturation attack)"
+  "The maximum number of tracked files (to prevent saturation attack)"
     int_option 100
 
 let max_tracker_reply = define_option bittorrent_section ["max_tracker_reply"]
-  "The maximal number of peers returned by the tracker"
+  "The maximum number of peers returned by the tracker"
     int_option 20
 
 let tracker_force_local_torrents = define_option bittorrent_section ["tracker_force_local_torrents"]
-  "The tracker will check the torrent file is available if an announce request is received"
+  "The tracker will track only torrents available locally"
     bool_option true
 
 let tracker_use_key = define_option bittorrent_section ["tracker_use_key"]
@@ -117,11 +116,11 @@ let tracker_use_key = define_option bittorrent_section ["tracker_use_key"]
     bool_option true
 
 let default_tracker = define_option bittorrent_section ["default_tracker"]
-    "Let you define a default tracker for creating torrents (leave empty for mlnet tracker)"
+    "Default tracker for creating torrents (leave empty for builtin tracker)"
     string_option ""
 
 let default_comment = define_option bittorrent_section ["default_comment"]
-    "Let you define a default comment for creating torrents"
+    "Default comment for creating torrents"
     string_option ""
 
 
@@ -144,44 +143,75 @@ let int_of_string v =
 
 let void_message = Bencode.encode (
     Dictionary [
-      String "interval", Int 600L;
-      String "peers", List []
+      "interval", Int 600L;
+      "peers", List []
     ])
 
+let new_tracker info_hash =
+  if !ntracked_files < !!max_tracked_files then
+    let tracker = {
+        tracker_id = info_hash;
+        tracker_table = Hashtbl.create 13;
+        tracker_peers = Fifo.create ();
+        tracker_message_time = 0;
+        tracker_message_content = "";
+        tracker_downloaded = 0;
+        tracker_complete = 0;
+        tracker_incomplete = 0;
+        tracker_last = (int_of_float (Unix.gettimeofday ()));
+      } in
+    incr ntracked_files;
+    if !verbose_msg_servers then
+      lprintf_nl "Start tracking torrent [%s]" (Sha1.to_hexa info_hash);
+    Hashtbl.add tracked_files info_hash tracker;
+    if not (List.mem info_hash !!tracked_files_list) then
+      tracked_files_list =:= info_hash :: !!tracked_files_list;
+    tracker
+  else
+    failwith (Printf.sprintf "[BT] Too many tracked files (%d)" !ntracked_files)
+
+let is_tracker_running () = !tracker_sock <> None
+
+let check_tracker () =
+  if not (is_tracker_running ()) then
+    failwith "Tracker is not running (either BT-tracker_port is 0 or stopped)"
+
+let tracker_url suffix =
+  check_tracker ();
+  Printf.sprintf "http://%s:%d/%s"
+    (Ip.to_string (CommonOptions.client_ip None))
+    !!tracker_port
+    (Url.encode suffix)
+
+let track_torrent filename info_hash =
+  check_tracker ();
+  if (Hashtbl.mem tracked_files info_hash) then
+    (if !verbose_msg_servers then lprintf_nl "Torrent [%s] is already tracked" (Sha1.to_hexa info_hash))
+  else
+    ignore (new_tracker info_hash);
+  tracker_url filename
+
+let get_default_tracker () =
+  match !!default_tracker with
+  | "" -> tracker_url "announce"
+  | s -> s
+
 let reply_has_tracker r info_hash peer_id peer_ip peer_port peer_key peer_left peer_event numwant no_peer_id  =
 
-  let tracker_ok = ref true in
   if !verbose_msg_servers then
-    lprintf_nl "tracker contacted for [%s]" (Sha1.to_hexa info_hash);
+    lprintf_nl "Tracker contacted for [%s]" (Sha1.to_hexa info_hash);
   let tracker = try
       Hashtbl.find tracked_files info_hash
     with Not_found ->
         if !!tracker_force_local_torrents then begin
-            tracker_ok := false;
-            lprintf_nl "Tracker rejected announce request for torrent [%s]\n" (Sha1.to_hexa info_hash);
+            lprintf_nl "Tracker rejected announce request for torrent [%s]" (Sha1.to_hexa info_hash);
             failwith "Unknown torrent"
           end;
         lprintf_nl "[BT] Need new tracker";
-        if !ntracked_files < !!max_tracked_files && !tracker_ok then
-          let tracker = {
-              tracker_id = info_hash;
-              tracker_table = Hashtbl.create 13;
-              tracker_peers = Fifo.create ();
-              tracker_message_time = 0;
-              tracker_message_content = "";
-              tracker_downloaded = 0;
-              tracker_complete = 0;
-              tracker_incomplete = 0;
-              tracker_last = (int_of_float (Unix.gettimeofday ()));
-            } in
-          incr ntracked_files;
-          Hashtbl.add tracked_files info_hash tracker;
-          tracker
-        else
-          failwith "[BT] Too many tracked files"
+        new_tracker info_hash
   in
 
-  let _ =
+  let peer =
     try
       let peer =
         Hashtbl.find tracker.tracker_table peer_id
@@ -221,6 +251,8 @@ let reply_has_tracker r info_hash peer_id peer_ip peer_port peer_key peer_left p
         void_message
     (* Reply with clients that could not connect to this tracker otherwise *)
     | "stopped" ->
+        Hashtbl.remove tracker.tracker_table peer_id;
+        Fifo.remove tracker.tracker_peers peer;
         if peer_left > 0 then
           tracker.tracker_incomplete <- tracker.tracker_incomplete - 1
         else
@@ -232,8 +264,10 @@ let reply_has_tracker r info_hash peer_id peer_ip peer_port peer_key peer_left p
        In fact, we should only return peers if this peer is behind a firewall.
      *)
 
-        if tracker.tracker_message_time < last_time () then
-
+        (* use cache *)
+        if tracker.tracker_message_time >= last_time () then
+          tracker.tracker_message_content
+        else
           let list = ref [] in
           lprintf_nl "Tracker collecting peers:";
           (try
@@ -258,31 +292,29 @@ let reply_has_tracker r info_hash peer_id peer_ip peer_port peer_key peer_left p
               Fifo.put tracker.tracker_peers p
           ) !list;
 
-(* reply by sending [head] *)
-
           let message =
             Dictionary [
-              String "interval", Int 600L;
-              String "min interval", Int 600L;
-              String "peers", List
+              "interval", Int 600L;
+              "min interval", Int 600L;
+              "peers", List
                 (List.map (fun p ->
                     if no_peer_id = 1 then
                       Dictionary [
-                        String "ip", String (Ip.to_string p.peer_ip);
-                        String "port", Int (Int64.of_int p.peer_port);
+                        "ip", String (Ip.to_string p.peer_ip);
+                        "port", Int (Int64.of_int p.peer_port);
                       ]
                     else
                       Dictionary [
-                        String "peer id", String
+                        "peer id", String
                           (Sha1.direct_to_string p.peer_id);
-                        String "ip", String (Ip.to_string p.peer_ip);
-                        String "port", Int (Int64.of_int p.peer_port);
+                        "ip", String (Ip.to_string p.peer_ip);
+                        "port", Int (Int64.of_int p.peer_port);
                       ]
                 ) !list);
-              String "downloaded", Int (Int64.of_int tracker.tracker_downloaded);
-              String "complete", Int (Int64.of_int tracker.tracker_complete);
-              String "incomplete", Int (Int64.of_int tracker.tracker_incomplete);
-              String "last", Int (Int64.of_int ((int_of_float (Unix.gettimeofday ())) - tracker.tracker_last));
+              "downloaded", Int (Int64.of_int tracker.tracker_downloaded);
+              "complete", Int (Int64.of_int tracker.tracker_complete);
+              "incomplete", Int (Int64.of_int tracker.tracker_incomplete);
+              "last", Int (Int64.of_int ((int_of_float (Unix.gettimeofday ())) - tracker.tracker_last));
             ]
           in
           let m = Bencode.encode message in
@@ -293,15 +325,13 @@ let reply_has_tracker r info_hash peer_id peer_ip peer_port peer_key peer_left p
               tracker.tracker_message_content <- m;
             end;
           m
-        else
-          tracker.tracker_message_content
   in
 
   r.reply_content <- message
 
 let http_handler t r =
   try
-    add_reply_header r "Server" "MLdonkey";
+    add_reply_header r "Server" (Printf.sprintf "MLdonkey/%s" Autoconf.current_version);
     add_reply_header r "Connection" "close";
 
     match r.get_url.Url.short_file with
@@ -388,11 +418,11 @@ let http_handler t r =
         Hashtbl.iter (fun info_hash tracker ->
             files_tracked :=
                 (Dictionary [
-                   String (Sha1.direct_to_string info_hash),
+                   (Sha1.direct_to_string info_hash),
                      Dictionary [
-                       String "complete", Int (Int64.of_int tracker.tracker_complete);
-                       String "downloaded", Int (Int64.of_int tracker.tracker_downloaded);
-                       String "incomplete", Int (Int64.of_int tracker.tracker_incomplete);
+                       "complete", Int (Int64.of_int tracker.tracker_complete);
+                       "downloaded", Int (Int64.of_int tracker.tracker_downloaded);
+                       "incomplete", Int (Int64.of_int tracker.tracker_incomplete);
                      ];
                  ]) :: !files_tracked;
             if !verbose_msg_servers then begin
@@ -408,7 +438,7 @@ let http_handler t r =
             lprintf_nl "f: (file hash) d: (downloaded) c: (complete) i: (incomplete)";
             lprint_string !log_tracked_files;
           end;
-        let message = Dictionary [ String "files", List !files_tracked ] in
+        let message = Dictionary [ "files", List !files_tracked ] in
         let m = Bencode.encode message in
         r.reply_content <- m
 
@@ -421,6 +451,7 @@ let http_handler t r =
     | filename ->
         if !verbose_msg_servers then
           lprintf_nl "Tracker received a request for .torrent: [%s]" filename;
+        let filename = Url.decode filename in
         if (Filename2.last_extension filename <> ".torrent") then
           failwith "Incorrect filename 1";
         for i = 1 to String.length filename - 1 do
@@ -443,6 +474,9 @@ in sub-directories in former versions. *)
 (*          lprintf " xx [%s]/[%s]\n" file_name filename; *)
           if Sys.file_exists file_name then file_name else
           let file_name = Filename.concat seeded_directory filename in
+(*          lprintf " xx [%s]/[%s]\n" file_name filename; *)
+          if Sys.file_exists file_name then file_name else
+          let file_name = Filename.concat old_directory filename in
 (*          lprintf " xx [%s]/[%s]\n" file_name filename; *)
           if Sys.file_exists file_name then file_name else
             failwith
@@ -461,7 +495,7 @@ in sub-directories in former versions. *)
       | _ ->
           let message =
             Dictionary [
-              String "failure reason", String (Printexc2.to_string e);
+              "failure reason", String (Printexc2.to_string e);
             ]
           in
           let m = Bencode.encode message in
@@ -550,7 +584,7 @@ let scan_tracked_directory _ =
   ) filenames
     *)
 
-let start_tracker () =
+let start_tracker tracked =
   if !!tracker_port <> 0 then begin
       let config = {
           bind_addr = if !!force_client_ip then Ip.to_inet_addr !!set_client_ip else Unix.inet_addr_any ;
@@ -558,13 +592,20 @@ let start_tracker () =
           requests = [];
           addrs = Ip_set.of_list [ Ip.RangeCIDR (Ip.null, 0) ];
           base_ref = "";
-	  use_ip_block_list = true;
+(* limit access to MLDonkey BT tracker based on IP blocklist *)
+          use_ip_block_list = true;
           default = http_handler;
         } in
       let sock = TcpServerSocket.create "BT tracker"
           (Ip.to_inet_addr !!client_bind_addr)
         !!tracker_port (Http_server.handler config) in
-      tracker_sock := Some sock
+      tracker_sock := Some sock;
+      List.iter begin fun info_hash ->
+        try
+          ignore (new_tracker info_hash)
+        with exn ->
+          lprintf_nl "Cannot start tracking %s : %s" (Sha1.to_hexa info_hash) (Printexc2.to_string exn)
+      end tracked
     end
 (*
   if !!tracker_port <> 0 then begin
@@ -591,35 +632,27 @@ let stop_tracker () =
 (* Every 600 seconds, refresh the peers list *)
 let clean_tracker_timer () =
   let time_threshold = last_time () - 3600 in
-  let trackers = ref [] in
 
-  if !verbose_msg_servers then lprintf_nl "clean_tracker_timer";
+  if !verbose_msg_servers then 
+    lprintf_nl "clean_tracker_timer - purging old peers";
   Hashtbl.iter (fun _ tracker ->
-      let list = ref [] in
       let old_peers = ref [] in
       Hashtbl.iter (fun _ peer ->
           if peer.peer_active < time_threshold then
             old_peers := peer :: !old_peers
-          else
+          (*else
           if Ip.usable peer.peer_ip then
-            list := peer :: !list)
+            list := peer :: !list*))
       tracker.tracker_table;
       List.iter (fun p ->
           Hashtbl.remove tracker.tracker_table p.peer_id
       ) !old_peers;
       Fifo.clear tracker.tracker_peers;
-      if !list <> [] then begin
-          List.iter (fun p -> Fifo.put tracker.tracker_peers p) !list;
-          trackers := tracker :: !trackers;
-        end;
-  ) tracked_files;
+      (* sync peers list *)
+      Hashtbl.iter (fun _ peer -> Fifo.put tracker.tracker_peers peer) tracker.tracker_table;
+  ) tracked_files
 
-  Hashtbl.clear tracked_files;
-  List.iter (fun t ->
-      Hashtbl.add tracked_files t.tracker_id t
-  ) !trackers
-
-let _ =
+let () =
   add_infinite_timer 600. clean_tracker_timer
 
 
