@@ -54,13 +54,13 @@ let lprintf_nl fmt =
   lprintf_nl2 log_prefix fmt
 
 (* Start new dowload from result *)
-let start_new_download u tth fdir fname fsize =
+let start_new_download u tth fdir fname fsize user group =
     try
       ignore (Hashtbl.find dc_shared_files_by_hash tth);
       if !verbose_download then lprintf_nl "Shared file with same hash exists (%s) (%s)" fname tth;
       None 
     with _ ->
-        let f = new_file tth fdir fname fsize in   (* ...create new file *)
+        let f = new_file tth fdir fname fsize user group in   (* ...create new file *)
         match (file_state f) with
         | FileDownloaded | FileShared -> if !verbose_download then lprintf_nl "File already downloaded"; None
         | FileDownloading -> if !verbose_download then lprintf_nl "File being downloaded"; None
@@ -82,10 +82,10 @@ let start_new_download u tth fdir fname fsize =
               Some f
 
 (* Start downloading of a file by user selection from resultlist *) 
-let start_result_download r =
+let start_result_download r user group =
   let filename = List.hd r.result_names in
   let rinfo = Hashtbl.find dc_result_info r.result_num in
-  let newfile = start_new_download (Some rinfo.user) rinfo.tth rinfo.directory filename r.result_size in
+  let newfile = start_new_download (Some rinfo.user) rinfo.tth rinfo.directory filename r.result_size user group in
   (match newfile with 
   | Some f -> as_file f.file_file (* return CommonFile.file *) 
   | _ -> raise Not_found )
@@ -1020,7 +1020,8 @@ msgWindow.location.reload();
         Printf.bprintf buf "Trying to download file: %s from user: %s\n" !sname uname;
         (try 
           let u = search_user_by_name uname in
-          ignore (start_new_download (Some u) tth !sdir !sname (Int64.of_string fsize))
+          let user = o.conn_user.ui_user in
+          ignore (start_new_download (Some u) tth !sdir !sname (Int64.of_string fsize) user user.user_default_group)
         with _ -> if !verbose_download then lprintf_nl "dcloadfile: No user found" )
     | _ ->
         if !verbose_unexpected_messages then
@@ -1144,6 +1145,15 @@ msgWindow.location.reload();
     html_mods_cntr_init ();
     if use_html_mods o then dc_info_html_header buf;
     let nservers = List.length !connected_servers in
+    let hashed =
+      [ Printf.sprintf "%d files" (Hashtbl.length dc_shared_files_by_hash) ] @
+      match !dc_files_to_hash with [] -> [] | l -> [ Printf.sprintf "%d queued" (List.length l) ] @
+      match !dc_tiger_computing with
+      | Some dcsh when dcsh.dc_shared_size > 0L ->
+        let progress = Int64.to_float dcsh.dc_shared_pos /. Int64.to_float dcsh.dc_shared_size *. 100. in
+        [ Printf.sprintf "hashing: %s (%3.0f%%)" (Filename.basename dcsh.dc_shared_fullname) progress ]
+      | _ -> []
+    in
     let list = [
       ("Hub supports", (DcProtocol.Supports.create_supports_string (HubSupports mldonkey_dc_hub_supports)) );
       ("Client supports", (DcProtocol.Supports.create_supports_string (ClientSupports mldonkey_dc_client_supports)) );
@@ -1152,8 +1162,9 @@ msgWindow.location.reload();
       ("Connected servers", (if nservers > 0 then string_of_int nservers else ""));
       ("  Server list:", empty_string ); ]      
       @ server_list @ [
-      ("Hubs", (Printf.sprintf "Normal:%d  Vipped:%d  Opped:%d" norm_hubs reg_hubs opped_hubs) ); ]
-    in  
+      ("Hubs", (Printf.sprintf "Normal:%d  Vipped:%d  Opped:%d" norm_hubs reg_hubs opped_hubs) );
+      ("Hashed", String.concat ", " hashed);
+    ] in
     let counter = ref 0 in
     List.iter (fun (info,data) -> 
       dc_info_print info data line o;
