@@ -1124,7 +1124,7 @@ let rec parse magic s =
               raise Not_found
         end
     | 0xD4 -> (* 212 *)
-          let s = Autoconf.zlib__uncompress_string2 (String.sub s 1 (len-1)) in
+          let s = Zlib.uncompress_string2 (String.sub s 1 (len-1)) in
           let s = Printf.sprintf "%c%s" (char_of_int opcode) s in
           parse 227 s
 
@@ -1135,7 +1135,7 @@ let rec parse magic s =
       if !CommonOptions.verbose_unknown_messages then begin
           lprintf_nl "Unknown message From server: %s (magic %d)"
             (Printexc2.to_string e) magic;
-          let tmp_file = Filename.temp_file "comp" "pak" in
+          let tmp_file = Filename2.temp_file "comp" "pak" in
           File.from_string tmp_file s;
           lprintf_nl "Saved unknown packet %s" tmp_file;
           dump s;
@@ -1365,8 +1365,8 @@ let to_string m =
   (*
 let _ =
   let s = "abcdefghijklmnopqrstuvwxyz" in
-  let compressed = Autoconf.zlib__compress_string s in
-  let ss = Autoconf.zlib__uncompress_string2 compressed in
+  let compressed = Zlib.compress_string s in
+  let ss = Zlib.uncompress_string2 compressed in
   lprintf "[%s] <> [%s]\n" s (String.escaped ss);
   assert (s = ss);
   exit 2
