@@ -43,8 +43,8 @@ open FileTPOptions
 
 let log_prefix = "[FileTP]"
 
-let lprintf_nl fmt =
-  lprintf_nl2 log_prefix fmt
+let lprintf_nl ?exn fmt =
+  lprintf_nl2 ?exn log_prefix fmt
 
 let lprintf_n fmt =
   lprintf2 log_prefix fmt
