@@ -231,7 +231,7 @@ save it on disk in the next version. *)
               lprintf "[TTR] ttr loaded\n";
             let ttr = Buffer.contents buf in
             let tiger_pos = CommonUploads.tiger_pos nblocks in
-            let array = Array.create nblocks TigerTree.null in
+            let array = Array.make nblocks TigerTree.null in
             for i = 0 to nblocks - 1 do
               array.(i) <- TigerTree.direct_of_string 
                 (String.sub ttr ((tiger_pos + i) * 24) 24)
@@ -509,27 +509,29 @@ and get_from_client sock (c: client) =
                 ) d.download_ranges;
                 
                 lprintf "\n  Current blocks: ";
-(*          List.iter (fun b -> CommonSwarming.print_block b) d.download_blocks; *)
+(*          List.iter (fun b -> CommonSwarming.print_block b.up_block) d.download_blocks; *)
                 lprintf "\n\nFinding Range: \n";
               end;
             let range = 
               try
                 let rec iter () =
-                  match d.download_block with
-                    None -> 
+                  match d.download_blocks with
+                  | [] -> 
                       if !verbose_swarming then lprintf "No block\n";
                       (try CommonSwarming.verify_one_chunk swarmer with _ -> ());
-                      let b = CommonSwarming.find_block up in
+                      let _chunk, blocks = CommonSwarming.find_blocks up in
                       
                       if !verbose_swarming then begin
-                          lprintf "GOT BLOCK:\n";
+                          lprintf "GOT BLOCKS:\n";
                           CommonSwarming.print_uploaders swarmer;
-                          lprintf "Block Found: "; CommonSwarming.print_block b;
+                          lprintf "Blocks Found: "; 
+			  List.iter (fun b ->
+                            CommonSwarming.print_block b.up_block) blocks;
                         end;
                       
-                      d.download_block <- Some b;
+                      d.download_blocks <- blocks;
                       iter ()
-                  | Some b ->
+                  | blocks ->
 (*
                 if !verbose_swarming then begin
                     lprintf "Current Block: "; CommonSwarming.print_block b;
@@ -549,7 +551,7 @@ end;
                       with Not_found ->
                           if !verbose_swarming then 
                             lprintf "Could not find range in current block\n";
-                          d.download_block <- None;
+                          d.download_blocks <- [];
                           iter ()
                 in
                 iter ()
@@ -605,7 +607,7 @@ and disconnect_client c r =
               | Some up ->
                   d.download_uploader <- None;
                   CommonSwarming.unregister_uploader up;
-                  d.download_block <- None;
+                  d.download_blocks <- [];
                   d.download_ranges <- [];
           ) c.client_downloads;
           begin
@@ -700,6 +702,8 @@ by the bandwidth manager... 2004/02/03: Normally, not true anymore, it should
                     in
                     
                     c.client_host <- Some (ip, port);
+                    c.client_country_code <- None;
+                    check_client_country_code c;
                     set_client_state c Connecting;
                     c.client_sock <- Connection sock;
                     TcpBufferedSocket.set_closer sock (fun _ s ->
@@ -766,6 +770,7 @@ let push_handler cc gconn sock (first_line, headers) =
             
     in
     c.client_host <- Some (ip, port);
+    check_client_country_code c;
     match c.client_sock with
     | Connection _ -> 
         if !verbose_msg_clients then begin
@@ -995,7 +1000,7 @@ let get_handler get_request cc gconn sock (first_line, headers) =
             if get_request then
               let pos = uc.uc_chunk_pos in
               let to_write = uc.uc_chunk_end -- pos in
-              let rlen = mini (max_refill sock) (Int64.to_int to_write) in
+              let rlen = min (max_refill sock) (Int64.to_int to_write) in
               if !verbose_msg_clients then
                 lprintf "[GUP] to_write: %d/%Ld/%d\n" rlen to_write
                   (remaining_to_write sock);
@@ -1039,7 +1044,7 @@ let get_handler get_request cc gconn sock (first_line, headers) =
 let listen () =
   try
     let sock = TcpServerSocket.create "gnutella client server" 
-        Unix.inet_addr_any
+        (Ip.to_inet_addr !!client_bind_addr)
         !!client_port
         (fun sock event ->
           match event with
