@@ -77,8 +77,8 @@ let recover_file file =
       if file_state file = FileDownloading then
         GnutellaServers.really_recover_file file        
 
-let download_file r user =
-  let file = GnutellaServers.really_download_file r user in
+let download_file r user group =
+  let file = GnutellaServers.really_download_file r user group in
   recover_file file;
   as_file file
 
@@ -220,6 +220,7 @@ that we can reuse queries *)
     !!client_port, "client_port TCP+UDP";
     ]);
   network.op_network_porttest_result <- (fun _ -> PorttestNotAvailable);
+  network.op_network_check_upload_slots <- (fun _ -> ());
   network.op_network_share <- (fun fullname codedname size ->
       (*
       lprintf "*************** op_network_share %s\n
@@ -318,6 +319,10 @@ let _ =
          | None -> None 
 	 | Some swarmer -> 
 	     Some (CommonSwarming.chunks_verified_bitmap swarmer));
+        P.file_chunk_size = (match file.file_swarmer with
+         | None -> None
+	 | Some t ->
+	     Some (List.map (fun t -> t.CommonSwarming.t_chunk_size) t.CommonSwarming.t_s.CommonSwarming.s_networks));
         P.file_availability =   [network.network_num,
            (match file.file_swarmer with
            None -> "" | Some swarmer ->
@@ -383,7 +388,7 @@ let _ =
       List2.tail_map (fun s -> as_server s.server_server)
       !connected_servers
   );
-  network.op_network_parse_url <- (fun url user ->
+  network.op_network_parse_url <- (fun url user group ->
       match String2.split (String.escaped url) '|' with
       | "gnut://" :: "server" :: ip :: port :: _ ->  
           let ip = Ip.addr_of_string ip in
@@ -415,7 +420,7 @@ let _ =
               (* Start a download for this file *)
               let rs = new_result name size [] uids [] in
               let r = IndexedResults.get_result rs in
-              let file = download_file r user in
+              let file = download_file r user group in
               CommonInteractive.start_download file;
               "started Gnutella download", true
             end
