@@ -39,7 +39,7 @@ let _ =
 let client_port = define_option gnutella_section ["client_port"]
     ~restart: true
     "The port to bind the client to"
-    int_option GnutellaNetwork.port
+    port_option GnutellaNetwork.port
   
 let gnutella_experimental = define_option gnutella_section
     ["experimental"]
@@ -53,19 +53,12 @@ let gnutella_hostfiles = define_option gnutella_section
   [
     "http://cache.kicks-ass.net:8000/";
     "http://g2cache.theg2.net/gwcache/lynnx.asp";
-    "http://galvatron.dyndns.org:59009/gwcache";
-    "http://gcache.sexter.com:8080/gwc/";
     "http://gwcrab.sarcastro.com:8001";
     "http://gwebcache.bearshare.net/";
     "http://gwebcache.bearshare.net/gcache.php";
-    "http://intense.homelinux.coww.xolox.nl/gwebcache/";
-    "http://kisama.ath.cx:8080/";
-    "http://krill.shacknet.nu:20095/gwc";
-    "http://loot.alumnigroup.org/";
     "http://pokerface.ibiza.bishopston.net:3558/";
     "http://t.az.is.teh.r0x0r.gtkg.de/";
     "http://tribaldance.ibiza.bishopston.net:3558/";
-    "http://www.deepnetexplorer.co.uk/webcache/";
   ]
 
 let urlfiles = define_option gnutella_section 
@@ -73,7 +66,9 @@ let urlfiles = define_option gnutella_section
   "A list of urlfile urls"
     (list_option string_option)
   [
+(*
     "http://loot.alumnigroup.org/";
+*)
   ]
   
 let redirectors = define_option gnutella_section 
