@@ -271,12 +271,6 @@ let replace_char s c1 c2 =
     if s.[i] == c1 then s.[i] <- c2
   done
 
-let shorten max s =
-  let len = String.length s in
-  if len > max then 
-    String.sub s 0 max
-  else s
-
 let stem s =
   let s = String.lowercase (String.copy s) in
   for i = 0 to String.length s - 1 do
@@ -291,7 +285,7 @@ let map f s =
   let len = String.length s in
   if len = 0 then [||] else
   let v = f s.[0] in
-  let array = Array.create len v in
+  let array = Array.make len v in
   for i = 1 to len -1 do 
     array.(i) <- f s.[i]
   done;
@@ -328,3 +322,19 @@ let for_all p s =
     i >= l || p s.[i] && aux (i+1) in
   aux 0
 
+let hex_string_of_string s =
+  let buf = Buffer.create 100 in
+  String.iter (fun c ->
+    Printf.bprintf buf "%02x " (int_of_char c)
+  ) s;
+  Buffer.contents buf
+
+let ( |> ) x f = f x
+
+let dehtmlize =
+  let br_regexp = Str.regexp_case_fold "<br>" in
+  let tag_regexp = Str.regexp "<[^>]*>" in
+  fun s ->
+    s
+    |> Str.global_replace br_regexp "\n"
+    |> Str.global_replace tag_regexp ""
