@@ -33,7 +33,7 @@ external zlib_version : unit -> string = "camlzip_zlibversion"
 let zlib_version_num () =
   begin
     try
-      let s = Printf.sprintf "%s" (zlib_version ()) in s
+      zlib_version ()
     with e -> ""
   end
 
@@ -117,7 +117,7 @@ let gzip_string ?(level = 6) inbuf =
   let write_int32 wbuf n =
     let r = ref n in
     for i = 1 to 4 do
-      Buffer.add_char wbuf (char_of_int (Int32.to_int (Int32.logand !r (Int32.of_int 255))));
+      Buffer.add_char wbuf (char_of_int (Int32.to_int (Int32.logand !r 0xffl)));
       r := Int32.shift_right_logical !r 8
     done
   in
@@ -143,10 +143,10 @@ let uncompress ?(header = true) refill flush =
       let incount = refill inbuf in
       if incount = 0 then uncompr_finish true else uncompr 0 incount
     end else begin
-      let (_, used_in, used_out) =
+      let (finished, used_in, used_out) =
         inflate zs inbuf inpos inavail outbuf 0 buffer_size Z_SYNC_FLUSH in
       flush outbuf used_out;
-      uncompr (inpos + used_in) (inavail - used_in)
+      if not finished then uncompr (inpos + used_in) (inavail - used_in)
     end
   and uncompr_finish first_finish =
     (* Gotcha: if there is no header, inflate requires an extra "dummy" byte
