@@ -27,12 +27,13 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 Boston, MA  02110-1301, USA.
 */
 
-/* $Id: zlibstubs.c,v 1.6 2009/02/24 18:34:31 spiralvoice Exp $ */
+/* $Id$ */
 
 /* Stub code to interface with Zlib */
 
 #include "../../../config/config.h"
 
+#include <stdint.h>
 #include <zlib.h>
 
 #ifdef USE_BZIP2
@@ -191,7 +192,7 @@ value camlzip_inflateEnd(value vzs)
 
 value camlzip_update_crc32(value crc, value buf, value pos, value len)
 {
-  return copy_int32(crc32((uint32) Int32_val(crc), 
+  return copy_int32(crc32((uint32_t) Int32_val(crc),
                           &Byte_u(buf, Long_val(pos)),
                           Long_val(len)));
 }
