@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with mldonkey; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
 #ifndef _TIGER_H
@@ -30,6 +30,6 @@ typedef unsigned char byte;
 #define TREE_DEPTH 10
 
 
-void tiger_hash(char prefix, char *s, long len, unsigned char *digest);
-unsigned long tiger_block_size(unsigned long len);
+void tiger_hash(char prefix, char *s, OFF_T len, unsigned char *digest);
+OFF_T tiger_block_size(OFF_T len);
 #endif
