@@ -94,6 +94,8 @@ val dummy : t
 
 val destroyed : t -> bool
 
+type fstype = [ `Win | `Posix | `Mac | `Unknown ]
+
 val bsize : string -> int64 option
 val blocks : string -> int64 option
 val bfree : string -> int64 option
@@ -105,6 +107,7 @@ val diskused : string -> int64 option
 val percentused : string -> int option
 val percentfree : string -> int option
 val filesystem : string -> string
+val filesystem_type : string -> fstype
 val subfile_tree_map : t -> (string -> int64 -> int64 -> int64-> unit)  ->  unit
 val find_file : t -> int64 -> (string * int64 * int64)
 val find_file_index : t -> int -> (string * int64 * int64)
