@@ -194,6 +194,13 @@ let string_of_reason c =
   | Closed_for_exception e -> Printf.sprintf "exception %s"
         (Printexc2.to_string e)
 
+let string_of_basic_event = function
+| CLOSED s -> Printf.sprintf "CLOSED %s" (string_of_reason s)
+| RTIMEOUT -> "RTIMEOUT"
+| LTIMEOUT -> "LTIMEOUT"
+| WTIMEOUT -> "WTIMEOUT"
+| CAN_READ -> "CAN_READ"
+| CAN_WRITE -> "CAN_WRITE"
 
 (*************************************************************************)
 (*                                                                       *)
@@ -204,15 +211,9 @@ let string_of_reason c =
 let minf (x: float) (y: float) =
   if x > y then y else x
 
-let mini (x: int) (y: int) =
-  if x > y then y else x
-
 let maxf (x: float) (y: float) =
   if x < y then y else x
 
-let maxi (x: int) (y: int) =
-  if x < y then y else x
-
 (*************************************************************************)
 (*                                                                       *)
 (*                         Some functions                                *)
@@ -259,13 +260,17 @@ let sprint_socket s =
 (*                                                                       *)
 (*************************************************************************)
 
+let exn_log name f x = 
+  try 
+    f x
+  with e -> 
+    lprintf_nl "[bS] %s : unexpected exn %s" name (Printexc2.to_string e)
+
 let close t msg =
   if t.fd <> dummy_fd then begin
       if !debug then
-          lprintf_nl "[bS] CLOSING: %s" (sprint_socket t);
-      (try
-          Unix.close t.fd;
-          with _ -> ());
+          lprintf_nl "[bS] CLOSING: %s (%s)" (sprint_socket t) (string_of_reason msg);
+      exn_log "close" Unix.close t.fd;
       t.fd <- dummy_fd;
       closed_tasks := t :: !closed_tasks;
       t.closed <- true;
@@ -345,7 +350,7 @@ let create_blocking name fd handler =
 
 let create name fd handler =
   MlUnix.set_nonblock fd;
-  if not Autoconf.windows then setsockopt fd SO_KEEPALIVE !socket_keepalive;
+  if not (Autoconf.windows || Autoconf.system="solaris") then setsockopt fd SO_KEEPALIVE !socket_keepalive;
   create_blocking name fd handler
 
 
@@ -384,18 +389,36 @@ let rec iter_task old_tasks time =
 (*                                                                       *)
 (*************************************************************************)
 
-let rec iter_timer timers time =
+let rec iter_timer_filter timers time acc =
   match timers with
-    [] -> []
+    [] -> acc
   | t :: timers ->
       if t.applied then
-        iter_timer timers time
+        iter_timer_filter timers time acc
       else
         begin
           timeout := minf (t.next_time -. time) !timeout;
-          t :: (iter_timer timers time)
+          iter_timer_filter timers time (t::acc)
         end
 
+(* fast version that doesn't allocate new list if no timers have expired
+  TODO use double-linked list instead? *)
+let iter_timer timers time =
+  let rec loop l =
+    match l with
+    | [] -> timers
+    | t :: l ->
+      if t.applied then
+        (* need to filter, reiterate and rebuild the list *)
+        iter_timer_filter timers time []
+      else
+        begin
+          timeout := minf (t.next_time -. time) !timeout;
+          loop l
+        end
+  in
+  loop timers
+
 (*************************************************************************)
 (*                                                                       *)
 (*                         TIMERS                                        *)
@@ -453,7 +476,7 @@ let rec exec_hooks list =
   match list with
     [] -> ()
   | f :: tail ->
-      (try f () with _ -> ());
+      exn_log "hook" f ();
       exec_hooks tail
 
 (*************************************************************************)
@@ -468,19 +491,23 @@ let rec exec_tasks =
       (
         let time = !current_time in
         if not t.closed && t.next_rtimeout < time then
-          (try t.event_handler t RTIMEOUT with _ -> ());
+          exn_log "exec rtimeout" (t.event_handler t) RTIMEOUT;
         if not t.closed && t.next_wtimeout < time then
-          (try t.event_handler t WTIMEOUT with _ -> ());
+          exn_log "exec wtimeout" (t.event_handler t) WTIMEOUT;
         if not t.closed && t.lifetime < time then
-          (try t.event_handler t LTIMEOUT with _ -> ());
+          exn_log "exec ltimeout" (t.event_handler t) LTIMEOUT;
         if not t.closed && t.flags land can_read <> 0 then
-          (try
+          begin try
               t.next_rtimeout <- time +. t.rtimeout;
-              t.event_handler t CAN_READ with _ -> ());
+              t.event_handler t CAN_READ
+          with 
+          | Unix_error ((ECONNRESET | ETIMEDOUT | ECONNREFUSED), _, _) -> ()
+          | exn -> lprintf_nl "[bS] %s : unexpected exn exec can_read" (Printexc2.to_string exn)
+          end;
         if not t.closed && t.flags land can_write <> 0 then
-          (try
+          exn_log "exec can_write" (fun () ->
               t.next_wtimeout <- time +. t.wtimeout;
-              t.event_handler t CAN_WRITE with _ -> ());
+              t.event_handler t CAN_WRITE) ();
       );
       exec_tasks tail
 
@@ -496,7 +523,7 @@ let rec exec_timers = function
       (
         if (not t.applied) && t.next_time <= !current_time then begin
             t.applied <- true;
-            try t.time_handler t with _ -> ()
+            begin try t.time_handler t with _ -> () end (* exn_log -> many Fifo.empty *)
           end
       );
       exec_timers tail
@@ -511,19 +538,12 @@ let loop () =
   add_infinite_timer 1.0 (fun _ ->
       if !verbose_bandwidth > 0 then
         lprintf_nl "[BW1] Resetting bandwidth counters";
-      List.iter (fun f -> try f () with _ -> ()) !bandwidth_second_timers
+      List.iter (fun f -> exn_log "reset bw ctr" f ()) !bandwidth_second_timers
   );
-  let loop_time = ref 0. in
   while true do
     try
-      let time = 
- 	let new_time = update_time () in
- 	let dynamic_loop_delay =  !loop_time +. !loop_delay -. new_time in
-        if dynamic_loop_delay > 0. then begin
- 	  (try select [] dynamic_loop_delay;  with _ -> ());
- 	  update_time ()
- 	end else new_time in
-      loop_time := time;
+      if !loop_delay > 0. then (try select [] !loop_delay;  with _ -> ());
+      let _ = update_time () in
       exec_tasks !fd_tasks;
       exec_hooks !after_select_hooks;
       exec_timers !timers;
@@ -533,7 +553,7 @@ let loop () =
           [] -> ()
         | t :: tail ->
             closed_tasks := tail;
-            (try t.event_handler t (CLOSED t.error) with _ -> ());
+            exn_log "exec closed" (t.event_handler t) (CLOSED t.error)
       done;
 
 (*      lprintf "before iter_timer\n"; *)
