@@ -73,7 +73,7 @@ let tcp_handler t sock event =
     begin
      try
       let s,id = Unix.accept (fd sock) in
-      if !verbose_bandwidth > 1 then lprintf "[BW2 %6d] accept on %s\n" (last_time ()) t.name;
+      if !verbose_bandwidth > 1 then lprintf_nl "[BW2 %6d] accept on %s" (last_time ()) t.name;
       (match t.accept_control with
           None -> () | Some cc -> 
             cc.nconnections_last_second <- cc.nconnections_last_second + 1);
@@ -88,13 +88,13 @@ let tcp_handler t sock event =
       
 let dummy_sock = Obj.magic 0  
   
-let create name addr port handler =
+let create name addr port ?(backlog = 3) handler =
   try
     let fd = Unix.socket Unix.PF_INET Unix.SOCK_STREAM 0 in
     Unix.setsockopt fd Unix.SO_REUSEADDR true; 
     MlUnix.set_close_on_exec fd;  
     Unix.bind fd (Unix.ADDR_INET ((*Unix.inet_addr_any*) addr, port));
-    Unix.listen fd 3;
+    Unix.listen fd backlog;
     let t = {
         name = name;
         sock = dummy_sock;
@@ -107,15 +107,16 @@ let create name addr port handler =
     t.sock <- sock;
     t
   with e ->
+    lprint_newline ();
     lprintf "Exception: %s at port %d\n" (Printexc2.to_string e) port;
     match e with
       Unix.Unix_error (Unix.EADDRINUSE, _, _) -> 
 	lprintf "This is normally caused by another application currently using this port.\n";
 	lprintf "Close that application and restart MLDonkey, exiting...\n";
-	Pervasives.exit 0
+	Pervasives.exit 69
       | _ -> raise e
   
-let create_connections_contoler name f =
+let create_connections_controler name f =
   let cc = {
       cc_name = name;
       nconnections_last_second = 0;
@@ -134,10 +135,12 @@ let _ =
       
       if !verbose_bandwidth > 0 then begin
           if !nconnections_last_second > 0 then
-            lprintf "[BW1 %6d] %d incoming connections last second:\n" (last_time ())  !nconnections_last_second;
+            lprintf_nl "[BW1 %6d] %d incoming connections last second:"
+              (last_time ())  !nconnections_last_second;
           List.iter (fun cc ->
               if cc.nconnections_last_second > 0 then
-                lprintf "[BW1 %6d]     %20s: %d incoming connections\n" (last_time ()) cc.cc_name cc.nconnections_last_second
+                lprintf_nl "[BW1 %6d]     %20s: %d incoming connections"
+                  (last_time ()) cc.cc_name cc.nconnections_last_second
           ) !connections_controlers
         end;
       
